@@ -1,13 +1,16 @@
-package Dist::Zilla::Plugin::DualLife;
-# git description: 0.03-12-gbb9762c
-$Dist::Zilla::Plugin::DualLife::VERSION = '0.04';
+package Dist::Zilla::Plugin::DualLife; # git description: v0.04-20-g61fcaa9
 # ABSTRACT: Distribute dual-life modules with Dist::Zilla
+# KEYWORDS: Makefile.PL core dual-life install INSTALLDIRS
+
+our $VERSION = '0.05';
 
 use Moose;
 use List::Util 'first';
 use namespace::autoclean;
 
-with 'Dist::Zilla::Role::InstallTool';
+with
+    'Dist::Zilla::Role::ModuleMetadata',
+    'Dist::Zilla::Role::InstallTool';
 
 #pod =head1 SYNOPSIS
 #pod
@@ -51,13 +54,6 @@ with 'Dist::Zilla::Role::InstallTool';
 has entered_core => (
     is => 'ro',
     isa => 'Str',
-    lazy => 1,
-    default => sub {
-        my $self = shift;
-        (my $name = $self->zilla->name) =~ s/-/::/g;
-        require Module::CoreList;
-        return Module::CoreList->first_release($name);
-    },
 );
 
 #pod =attr eumm_bundled
@@ -72,23 +68,45 @@ has entered_core => (
 has eumm_bundled => (
     is => 'ro',
     isa => 'Bool',
-    default => "0",
+    default => 0,
 );
 
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        $self->entered_core ? ( entered_core => $self->entered_core ) : (),
+        eumm_bundled => $self->eumm_bundled ? 1 : 0,
+    };
+
+    return $config;
+};
+
 sub setup_installer {
     my ($self) = @_;
 
-    my $entered = $self->entered_core;
+    my $entered = $self->entered_core || do {
+        my $mmd = $self->module_metadata_for_file($self->zilla->main_module);
+        my $module = ($mmd->packages_inside)[0];
+        require Module::CoreList;
+        Module::CoreList->VERSION('2.19');
+        Module::CoreList->first_release($module);
+    };
 
-    if ($entered > 5.011000 && not $self->eumm_bundled) {
-        $self->log('this module entered core after 5.011 - nothing to do here');
-        return;
+    if (not $self->eumm_bundled)
+    {
+        # technically this only checks if the module is core, not dual-lifed, but a
+        # separate repository shouldn't exist for non-dual modules anyway
+        $self->log_fatal('this module is not dual-life!') if not $entered;
+
+        if ($entered > 5.011000) {
+            $self->log('this module entered core after 5.011 - nothing to do here');
+            return;
+        }
     }
 
-    # technically this only checks if the module is core, not dual-lifed, but a
-    # separate repository shouldn't exist for non-dual modules anyway
-    $self->log_fatal('this module is not dual-life!') if not $entered;
-
     my $makefile = first { $_->name eq 'Makefile.PL' } @{ $self->zilla->files };
     $self->log_fatal('No Makefile.PL. It needs to be provided by another plugin')
         unless $makefile;
@@ -126,7 +144,7 @@ Dist::Zilla::Plugin::DualLife - Distribute dual-life modules with Dist::Zilla
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -178,13 +196,6 @@ core prior to v5.12 so they take precedence.
 
 Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Florian Ragwitz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Karen Etheridge David Golden
@@ -201,4 +212,11 @@ David Golden <dagolden@cpan.org>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
